package com.jqtx.windows.common.factory;

import cn.hutool.core.util.ObjectUtil;
import com.alibaba.fastjson.JSONObject;
import com.jqtx.windows.common.exception.BizException;
import com.jqtx.windows.infrastructure.enums.ExceptionCodeEnum;
import com.jqtx.windows.utils.AbcRsaUtil;
import com.jqtx.windows.web.config.RouterConfig;
import com.jqtx.windows.web.response.JsonResult;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

@Service
public class CommandProxy {

    @Value("${abc.publicKey}")
    private String publicKey;

    @Value("${abc.yy_privateKey}")
    private String YyPpivateKey;

    public JsonResult call(String request,String method){
        AbstractCommand command = RouterConfig.getCommand(method);
        if(ObjectUtil.isNull(command)){
            return JsonResult.success(ExceptionCodeEnum.SYSTEM_ERROR);
        }
        JSONObject jsonObject = JSONObject.parseObject(request);
        String requestBody = jsonObject.getString("content");
        String sign = jsonObject.getString("sign");
        String appId = jsonObject.getString("appId");
        String decodeBody = AbcRsaUtil.decodeParam(requestBody, sign, YyPpivateKey, publicKey);
        if(StringUtils.isBlank(decodeBody)){
            throw new BizException(ExceptionCodeEnum.BIZ_AUTH_ERROR);
        }
        ChannelConfig channelConfig = new ChannelConfig();
        channelConfig.setAppId(appId);
        this.setLocalContext(requestBody,channelConfig);
        return command.doAction();
    }

    public void setLocalContext(String requestBody, ChannelConfig channelConfig) {
        RuntimeContext context = RuntimeContextHolder.currentRuntimeContext();
        if (context == null) {
            context = new RuntimeContext();
        }
        context.setRequestBody(requestBody);
        context.setChannelConfig(channelConfig);
        RuntimeContextHolder.setCurrentRuntimeContext(context);
    }
}
